@@ -17,6 +17,16 @@ with DAG(
 ) as dag:
 
     latest_only = LatestOnlyOperator(task_id="latest_only", dag=dag)
-    run_sync = HightouchTriggerSyncOperator(task_id="run_my_sync", sync_id=1)
+
+    # This task runs async, and doesn't poll for status or fail on error
+    run_async = HightouchTriggerSyncOperator(task_id="run_async", sync_id=4)
+
+    # This tasks polls the API until the Hightouch Sync completes or errors.
+    # Warnings are considered errors, but this can be turned off with the
+    # specified flag
+    run_sync = HightouchTriggerSyncOperator(
+        task_id="run_sync", sync_id=5, synchronous=True, error_on_warning=True
+    )
 
     latest_only >> run_sync
+    latest_only >> run_async
